@@ -3,7 +3,10 @@
 // // Licensed under the MIT license, see the LICENSE file or <https://opensource.org/licenses/MIT>
 #![cfg_attr(feature = "dox", feature(doc_cfg))]
 
-pub use ffi::*;
+use ffi::*;
+use glib::translate::{FromGlibPtrFull, FromGlibPtrNone};
+use std::ptr;
+
 pub use gio;
 pub use glib;
 
@@ -12,8 +15,6 @@ pub use glib::{
     VariantType,
 };
 
-pub mod prelude;
-
 #[macro_use]
 mod rt;
 
